@@ -4,7 +4,7 @@ from ..manifest.man import ssm
 from sys import stderr
 from git import Repo
 from itertools import starmap
-import shutil
+from subprocess import run
 from shutil import rmtree
 
 __all__ = [
@@ -136,7 +136,8 @@ def remote_push_manifest(
         else:
             repo.git.commit("-m", commit_msg)
             print(f"Commit [{repo_dir=!s}] ⠶ {commit_msg}", file=stderr)
-            repo.remotes.origin.push(refspec=refspec)
+            origin = repo.remotes.origin
+            origin.push(refspec=refspec)
             print(f"⇢ Pushing ⠶ {origin.name}", file=stderr)
     ssm.check_manifest()
     return
@@ -160,7 +161,7 @@ def remote_pull_manifest(specific_domains=None):
             print(f"Skipping '{repo_dir=!s}' (doesn't exist)", file=stderr)
             continue  # simply do not touch for now
         repo = Repo(repo_dir)
-        origin = repo.remote(name="origin")
+        origin = repo.remotes.origin
         origin.pull()  # not checked if returned Pull object stores useful info
         print(f"⇢ Pulling ⠶ {origin.name}", file=stderr)
     ssm.check_manifest()
@@ -169,23 +170,13 @@ def remote_pull_manifest(specific_domains=None):
 def copy_static_assets(repo_dir, from_name="static", to_name="site", purge=False):
     static_dir = repo_dir / from_name
     site_dir = repo_dir / to_name
-    for cp_path in static_dir.iterdir():
-        cp_subpath = cp_path.relative_to(static_dir)
-        target_path = site_dir / cp_subpath
-        if target_path.exists():
-            if not purge:
-                print(
-                    f"Not overwriting {cp_path=} at {target_path=} "
-                    "(static target already exists)"
-                )
-                continue
-            else:
-                rmtree(target_path) if target_path.is_dir() else target_path.unlink()
-        # Target path now doesn't exist (either already or has been purged)
-        if cp_path.is_dir():
-            shutil.copytree(cp_path, target_path)
-        else:
-            shutil.copy(cp_path, target_path.parent)
+    if purge and site_dir.exists():
+        rmtree(site_dir)
+    site_dir.mkdir(exist_ok=not purge)
+    clobber_flag = [] if purge else ["--no-clobber"]
+    cp_cmd = ["cp", "-r", *clobber_flag, f"{static_dir!s}", f"{site_dir!s}"]
+    if run(cp_cmd).returncode != 0:
+        raise ValueError(f"Failed to copy {static_dir=} to {site_dir=}")
 
 
 def stash_transfer_site_manifest(
@@ -252,7 +243,8 @@ def stash_transfer_site_manifest(
         else:
             repo.git.commit("-m", commit_msg)
             print(f"Commit [{repo_dir=!s}] ⠶ {commit_msg}", file=stderr)
-            repo.remotes.origin.push(refspec=checkout_branch)
+            origin = repo.remotes.origin
+            origin.push(refspec=checkout_branch)
             print(f"⇢ Pushing ⠶ {origin.name} ({checkout_branch})", file=stderr)
         if reset_branch:
             repo.git.checkout(initial_repo_branch)
